package cn.sh.stc.sict.theme.hphy.controller.mp;

import cn.hutool.core.collection.CollUtil;
import cn.hutool.core.lang.Validator;
import cn.hutool.core.util.RandomUtil;
import cn.hutool.json.JSONUtil;
import cn.sh.stc.sict.cloud.common.core.constant.Constant;
import cn.sh.stc.sict.cloud.common.core.util.R;
import cn.sh.stc.sict.cloud.common.core.util.ValidateCodeUtil;
import cn.sh.stc.sict.theme.hpgp.model.HpgpDepartmentRank;
import cn.sh.stc.sict.theme.hpgp.service.HpgpDepartmentRankService;
import cn.sh.stc.sict.theme.hphy.service.HpDeptInfoService;
import cn.sh.stc.sict.theme.hphy.wd.*;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.redis.core.RedisTemplate;
import org.springframework.data.redis.core.StringRedisTemplate;
import org.springframework.web.bind.annotation.*;

import java.util.List;
import java.util.stream.Collectors;

/**
 * @author F_xh
 */
@Slf4j
@RestController
@RequestMapping("/c/wd")
@Api(tags = "[C]wanda相关接口")
public class WDController {

    @Autowired
    private StringRedisTemplate redisTemplate;
    @Autowired
    private HpgpDepartmentRankService hpgpDepartmentRankService;
    @Autowired
    private HpDeptInfoService hpDeptInfoService;

    /**
     * 0. 发短信
     * 1. 医生查询
     * 2. 门诊信息查询
     * 3. 号源查询
     * 4. 测压厅信息
     * 5. 预约须知
     */

    @ApiOperation("发送短信")
    @PostMapping("/send/msg")
    public R sendMsg(@RequestParam("phone") String phone,
                     @ApiParam("类型：0-登录，1-注册") @RequestParam("type") Byte type) {
        boolean mobile = Validator.isMobile(phone);
        if (!mobile) {
            return new R().error("手机号错误！");
        }
        // 是否重复发送
        if(ValidateCodeUtil.hasPhoneKey(redisTemplate, phone, type)){
            return new R().success("短信已发送，请等待！");
        }
        String appName = "dx";
        String code = RandomUtil.randomNumbers(6);
        String msg = "您的验证码是：" + code;
        WanDaHttpUtil.sendMsg(phone, msg, appName);
        ValidateCodeUtil.saveCode(redisTemplate, phone, code, type);
        return new R().success("短信已发送，请等待！");
    }


    @ApiOperation("获取号源信息")
    @GetMapping("/num/info")
    public R getOrderNumberInfo(NumSourceInfo numSourceInfo) {

        // 医生查询所有号源能查到，查询指定类型号源差不多，20220715处理：查询所有，过滤
        String orderNumType = numSourceInfo.getOrderNumType();
        if(WanDaConstant.ORDER_TYPE_OUTP.equals(numSourceInfo.getOrderType())){
            numSourceInfo.setOrderNumType(null);
        }
        List<NumSourceInfo> list = WanDaHttpUtil.getOrderNumInfo(numSourceInfo);
        if(CollUtil.isEmpty(list)){
            return new R();
        }
        if(WanDaConstant.ORDER_TYPE_OUTP.equals(numSourceInfo.getOrderType())){
            List<NumSourceInfo> result = list.stream().filter(i -> orderNumType.equals(i.getOrderNumType())).collect(Collectors.toList());
            return new R(result);
        }else{
            return new R(list);
        }

//        if (CollUtil.isNotEmpty(list)) {
//            return R.builder().code(Constant.BYTE_YES).data(list).bizCode(Constant.INT_NO).build();
//        }
//
//        DeptInfo deptInfo = new DeptInfo();
//        deptInfo.setHosOrgCode(numSourceInfo.getHosOrgCode());
//        deptInfo.setOneDeptCode(numSourceInfo.getOneDeptCode());
//        deptInfo.setDeptCode(numSourceInfo.getDeptCode());
//        List<OutPatInfo> outPatInfo = WanDaHttpUtil.getResourceOutPatInfo(deptInfo);
//        if (CollUtil.isNotEmpty(outPatInfo)) {
//            numSourceInfo.setOrderType(WanDaConstant.ORDER_TYPE_CLINC);
//            numSourceInfo.setResourceCode(outPatInfo.get(0).getResourceCode());
//            list = WanDaHttpUtil.getOrderNumInfo(numSourceInfo);
//
//            return new R(list);
//        }
//        return new R().success(list);
    }

    @ApiOperation("获取测压亭列表")
    @GetMapping("/pressure/pavilion")
    public R getPressureStationList(){
        return new R();
    }

}
